import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_autoscaling_common
import aws_cdk.aws_cloudwatch
import aws_cdk.aws_iam
import aws_cdk.core
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-applicationautoscaling", "1.33.0", __name__[0:-6], "aws-applicationautoscaling@1.33.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
